TransmogCostCutter = CreateFrame("Frame");
TransmogCostCutter.lastScan = {};
function TransmogCostCutter:GetHiddenSourceDB()
	local hiddenItemSourceIDs = {
		[77344] = "Hidden Helm",
		[77343] = "Hidden Shoulder",
		[77345] = "Hidden Cloak",
		[104602] = "Hidden Chest",
		[83202] = "Hidden Shirt",
		[83203] = "Hidden Tabard",
		[104604] = "Hidden Bracer",
		[94331] = "Hidden Gloves",
		[84223] = "Hidden Belt",
		[104603] = "Hidden Boots",
	}
	
	local visualIDReplacements = {};
	
	for sourceID, sourceName in pairs(hiddenItemSourceIDs)do
		local hiddenItemSourceInfo = C_TransmogCollection.GetSourceInfo(sourceID);
		if(hiddenItemSourceInfo)then
			visualIDReplacements[hiddenItemSourceInfo.visualID] = sourceID;
		end
	end
	
	return visualIDReplacements;
end

function TransmogCostCutter:ScanTransmog(removeTransmogLocations)
	local transmogInfoProcessed = {};
	if(not WardrobeTransmogFrame)then return transmogInfoProcessed; end
	local playerActor = WardrobeTransmogFrame.ModelScene:GetPlayerActor();
	if(not playerActor)then return transmogInfoProcessed; end
	local transmogInfo = playerActor:GetItemTransmogInfoList();
	local replacementDB = self:GetHiddenSourceDB();
	for slot, slotInfo in pairs(transmogInfo)do
		local inventorySlotItemID = GetInventoryItemID("player", slot);
		local inventorySlotName = TransmogUtil.GetSlotName(slot);
		if(inventorySlotName and inventorySlotItemID)then
			local slotData = {};
			slotData.slotName = inventorySlotName;
			slotData.canHaveSecondaryAppearance = C_Transmog.CanHaveSecondaryAppearanceForSlotID(slot);
			local baseSourceID, baseVisualID, appliedSourceID, appliedVisualID, pendingSourceID, pendingVisualID, hasPendingUndo, isHideVisual, itemSubclass;
			
			-- Check Main
			slotData.transmogLocation = TransmogUtil.CreateTransmogLocation(inventorySlotName, Enum.TransmogType.Appearance, Enum.TransmogModification.Main);
			baseSourceID, baseVisualID, appliedSourceID, appliedVisualID, pendingSourceID, pendingVisualID, hasPendingUndo, isHideVisual, itemSubclass = C_Transmog.GetSlotVisualInfo(slotData.transmogLocation);
			if(pendingVisualID ~= 0 and pendingVisualID and replacementDB[pendingVisualID] and pendingVisualID ~= replacementDB[pendingVisualID])then
				slotData.primarySource = pendingSourceID;
				slotData.replacePrimary = replacementDB[pendingVisualID];
			end
			
			-- Check Secondary
			if(slotData.canHaveSecondaryAppearance)then
				slotData.secondaryTransmogLocation = TransmogUtil.CreateTransmogLocation(inventorySlotName, Enum.TransmogType.Appearance, Enum.TransmogModification.Secondary);
				baseSourceID, baseVisualID, appliedSourceID, appliedVisualID, pendingSourceID, pendingVisualID, hasPendingUndo, isHideVisual, itemSubclass = C_Transmog.GetSlotVisualInfo(slotData.secondaryTransmogLocation);
				if(pendingVisualID ~= 0 and pendingVisualID and replacementDB[pendingVisualID] and pendingVisualID ~= replacementDB[pendingVisualID])then
					slotData.secondarySource = pendingVisualID;
					slotData.replaceSecondary = replacementDB[pendingVisualID];
				end
			end
			
			if(removeTransmogLocations == true)then
				slotData.transmogLocation = nil;
				slotData.secondaryTransmogLocation = nil;
			end
			
			transmogInfoProcessed[slot] = slotData;
		end
	end
	return transmogInfoProcessed;
end

function TransmogCostCutter:SaveMoney()
local replacements = 0;
for slotID, slotInfo in pairs(self:ScanTransmog())do
	local slotReplaced = false;
	if(slotInfo.transmogLocation and slotInfo.replacePrimary)then
		slotReplaced = true;
		local pendingInfo = TransmogUtil.CreateTransmogPendingInfo(Enum.TransmogPendingType.Apply, slotInfo.replacePrimary);
		C_Transmog.SetPending(slotInfo.transmogLocation, pendingInfo);
		local oldLink = select(6, C_TransmogCollection.GetAppearanceSourceInfo(slotInfo.primarySource));
		local newLink = select(6, C_TransmogCollection.GetAppearanceSourceInfo(slotInfo.replacePrimary));
		--print("Primary Replacement", _G[slotInfo.slotName], (oldLink or slotInfo.primarySource), (newLink or slotInfo.replacePrimary));
	end
	if(slotInfo.secondaryTransmogLocation and slotInfo.replaceSecondary)then
		slotReplaced = true;
		local pendingInfo = TransmogUtil.CreateTransmogPendingInfo(Enum.TransmogPendingType.Apply, slotInfo.replaceSecondary);
		C_Transmog.SetPending(slotInfo.secondaryTransmogLocation, pendingInfo);
		local oldLink = select(6, C_TransmogCollection.GetAppearanceSourceInfo(slotInfo.secondarySource));
		local newLink = select(6, C_TransmogCollection.GetAppearanceSourceInfo(slotInfo.replaceSecondary));
		--print("Secondary Replacement", _G[slotInfo.slotName], (oldLink or slotInfo.secondarySource), (newLink or slotInfo.replaceSecondary));
	end
	if(slotReplaced == true)then
		replacements = replacements + 1;
	end
end
if(replacements > 0)then
	DEFAULT_CHAT_FRAME:AddMessage(("[TransmogCostCutter]: We made %s transmog |4replacement:replacements; to save you money."):format(replacements), 1, 1, 1);
end
end

function TransmogCostCutter:OnEvent(evt,...)
if(evt == "TRANSMOGRIFY_UPDATE")then
local transmogLocation, transmogAction = ...;
self:UnregisterEvent(evt);
self:SaveMoney();
self:RegisterEvent(evt);
end
end
function TransmogCostCutter:Init()
self:RegisterEvent("TRANSMOGRIFY_UPDATE");
self:SetScript("OnEvent", self.OnEvent)
end
TransmogCostCutter:Init()